"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withAsync = exports.useAsync = void 0;
var lodash_debounce_1 = __importDefault(require("lodash.debounce"));
var prop_types_1 = __importDefault(require("prop-types"));
var react_1 = __importStar(require("react"));
var useForceUpdate_1 = __importDefault(require("@restart/hooks/useForceUpdate"));
var usePrevious_1 = __importDefault(require("@restart/hooks/usePrevious"));
var propTypes_1 = require("../propTypes");
var utils_1 = require("../utils");
var propTypes = {
    /**
     * Delay, in milliseconds, before performing search.
     */
    delay: prop_types_1.default.number,
    /**
     * Whether or not a request is currently pending. Necessary for the
     * container to know when new results are available.
     */
    isLoading: prop_types_1.default.bool.isRequired,
    /**
     * Number of input characters that must be entered before showing results.
     */
    minLength: prop_types_1.default.number,
    /**
     * Callback to perform when the search is executed.
     */
    onSearch: prop_types_1.default.func.isRequired,
    /**
     * Options to be passed to the typeahead. Will typically be the query
     * results, but can also be initial default options.
     */
    options: prop_types_1.default.arrayOf(propTypes_1.optionType),
    /**
     * Message displayed in the menu when there is no user input.
     */
    promptText: prop_types_1.default.node,
    /**
     * Message displayed in the menu while the request is pending.
     */
    searchText: prop_types_1.default.node,
    /**
     * Whether or not the component should cache query results.
     */
    useCache: prop_types_1.default.bool,
};
/**
 * Logic that encapsulates common behavior and functionality around
 * asynchronous searches, including:
 *
 *  - Debouncing user input
 *  - Optional query caching
 *  - Search prompt and empty results behaviors
 */
function useAsync(props) {
    var allowNew = props.allowNew, _a = props.delay, delay = _a === void 0 ? 200 : _a, emptyLabel = props.emptyLabel, isLoading = props.isLoading, _b = props.minLength, minLength = _b === void 0 ? 2 : _b, onInputChange = props.onInputChange, onSearch = props.onSearch, _c = props.options, options = _c === void 0 ? [] : _c, _d = props.promptText, promptText = _d === void 0 ? 'Type to search...' : _d, _e = props.searchText, searchText = _e === void 0 ? 'Searching...' : _e, _f = props.useCache, useCache = _f === void 0 ? true : _f, otherProps = __rest(props, ["allowNew", "delay", "emptyLabel", "isLoading", "minLength", "onInputChange", "onSearch", "options", "promptText", "searchText", "useCache"]);
    var cacheRef = react_1.useRef({});
    var handleSearchDebouncedRef = react_1.useRef(null);
    var queryRef = react_1.useRef(props.defaultInputValue || '');
    var forceUpdate = useForceUpdate_1.default();
    var prevProps = usePrevious_1.default(props);
    var handleSearch = react_1.useCallback(function (query) {
        queryRef.current = query;
        if (!query || (minLength && query.length < minLength)) {
            return;
        }
        // Use cached results, if applicable.
        if (useCache && cacheRef.current[query]) {
            // Re-render the component with the cached results.
            forceUpdate();
            return;
        }
        // Perform the search.
        onSearch(query);
    }, [forceUpdate, minLength, onSearch, useCache]);
    // Set the debounced search function.
    react_1.useEffect(function () {
        handleSearchDebouncedRef.current = lodash_debounce_1.default(handleSearch, delay);
        return function () {
            handleSearchDebouncedRef.current &&
                handleSearchDebouncedRef.current.cancel();
        };
    }, [delay, handleSearch]);
    react_1.useEffect(function () {
        // Ensure that we've gone from a loading to a completed state. Otherwise
        // an empty response could get cached if the component updates during the
        // request (eg: if the parent re-renders for some reason).
        if (!isLoading && prevProps && prevProps.isLoading && useCache) {
            cacheRef.current[queryRef.current] = options;
        }
    });
    var getEmptyLabel = function () {
        if (!queryRef.current.length) {
            return promptText;
        }
        if (isLoading) {
            return searchText;
        }
        return emptyLabel;
    };
    var handleInputChange = react_1.useCallback(function (query, e) {
        onInputChange && onInputChange(query, e);
        handleSearchDebouncedRef.current &&
            handleSearchDebouncedRef.current(query);
    }, [onInputChange]);
    var cachedQuery = cacheRef.current[queryRef.current];
    return __assign(__assign({}, otherProps), { 
        // Disable custom selections during a search if `allowNew` isn't a function.
        allowNew: utils_1.isFunction(allowNew) ? allowNew : allowNew && !isLoading, emptyLabel: getEmptyLabel(), isLoading: isLoading, minLength: minLength, onInputChange: handleInputChange, options: useCache && cachedQuery ? cachedQuery : options });
}
exports.useAsync = useAsync;
function withAsync(Component) {
    var AsyncTypeahead = react_1.forwardRef(function (props, ref) { return react_1.default.createElement(Component, __assign({}, props, useAsync(props), { ref: ref })); });
    AsyncTypeahead.displayName = "withAsync(" + utils_1.getDisplayName(Component) + ")";
    // @ts-ignore
    AsyncTypeahead.propTypes = propTypes;
    return AsyncTypeahead;
}
exports.withAsync = withAsync;
