import PropTypes from 'prop-types';
import { HTMLProps, KeyboardEventHandler, MouseEventHandler } from 'react';
import { noop } from '../utils';
import { Size } from '../types';
interface ClearButtonProps extends Omit<HTMLProps<HTMLButtonElement>, 'size'> {
    label: string;
    onClick: MouseEventHandler<HTMLButtonElement>;
    onKeyDown: KeyboardEventHandler<HTMLButtonElement>;
    size?: Size;
}
/**
 * ClearButton
 *
 * http://getbootstrap.com/css/#helper-classes-close
 */
declare const ClearButton: {
    ({ className, label, onClick, onKeyDown, size, ...props }: ClearButtonProps): JSX.Element;
    propTypes: {
        label: PropTypes.Requireable<string>;
        onClick: PropTypes.Requireable<(...args: any[]) => any>;
        onKeyDown: PropTypes.Requireable<(...args: any[]) => any>;
        size: PropTypes.Requireable<Size>;
    };
    defaultProps: {
        label: string;
        onClick: typeof noop;
        onKeyDown: typeof noop;
    };
};
export default ClearButton;
