"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var prop_types_1 = __importDefault(require("prop-types"));
var react_1 = __importDefault(require("react"));
var utils_1 = require("../utils");
var propTypes = {
    children: prop_types_1.default.string.isRequired,
    highlightClassName: prop_types_1.default.string,
    search: prop_types_1.default.string.isRequired,
};
var defaultProps = {
    highlightClassName: 'rbt-highlight-text',
};
/**
 * Stripped-down version of https://github.com/helior/react-highlighter
 *
 * Results are already filtered by the time the component is used internally so
 * we can safely ignore case and diacritical marks for the purposes of matching.
 */
var Highlighter = function (_a) {
    var children = _a.children, highlightClassName = _a.highlightClassName, search = _a.search;
    if (!search || !children) {
        return react_1.default.createElement(react_1.default.Fragment, null, children);
    }
    var matchCount = 0;
    var remaining = children;
    var highlighterChildren = [];
    while (remaining) {
        var bounds = utils_1.getMatchBounds(remaining, search);
        // No match anywhere in the remaining string, stop.
        if (!bounds) {
            highlighterChildren.push(remaining);
            break;
        }
        // Capture the string that leads up to a match.
        var nonMatch = remaining.slice(0, bounds.start);
        if (nonMatch) {
            highlighterChildren.push(nonMatch);
        }
        // Capture the matching string.
        var match = remaining.slice(bounds.start, bounds.end);
        highlighterChildren.push(react_1.default.createElement("mark", { className: highlightClassName, key: matchCount }, match));
        matchCount += 1;
        // And if there's anything left over, continue the loop.
        remaining = remaining.slice(bounds.end);
    }
    return react_1.default.createElement(react_1.default.Fragment, null, highlighterChildren);
};
Highlighter.propTypes = propTypes;
Highlighter.defaultProps = defaultProps;
exports.default = Highlighter;
