"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHint = exports.defaultShouldSelect = void 0;
var invariant_1 = __importDefault(require("invariant"));
var react_1 = __importStar(require("react"));
var Context_1 = require("../core/Context");
var utils_1 = require("../utils");
// IE doesn't seem to get the composite computed value (eg: 'padding',
// 'borderStyle', etc.), so generate these from the individual values.
function interpolateStyle(styles, attr, subattr) {
    if (subattr === void 0) { subattr = ''; }
    // Title-case the sub-attribute.
    if (subattr) {
        /* eslint-disable-next-line no-param-reassign */
        subattr = subattr.replace(subattr[0], subattr[0].toUpperCase());
    }
    return ['Top', 'Right', 'Bottom', 'Left']
        .map(function (dir) { return styles["" + attr + dir + subattr]; })
        .join(' ');
}
function copyStyles(inputNode, hintNode) {
    if (!inputNode || !hintNode) {
        return;
    }
    var inputStyle = window.getComputedStyle(inputNode);
    /* eslint-disable no-param-reassign */
    hintNode.style.borderStyle = interpolateStyle(inputStyle, 'border', 'style');
    hintNode.style.borderWidth = interpolateStyle(inputStyle, 'border', 'width');
    hintNode.style.fontSize = inputStyle.fontSize;
    hintNode.style.height = inputStyle.height;
    hintNode.style.lineHeight = inputStyle.lineHeight;
    hintNode.style.margin = interpolateStyle(inputStyle, 'margin');
    hintNode.style.padding = interpolateStyle(inputStyle, 'padding');
    /* eslint-enable no-param-reassign */
}
function defaultShouldSelect(e, shouldSelect) {
    var shouldSelectHint = false;
    var currentTarget = e.currentTarget, key = e.key;
    if (key === 'ArrowRight') {
        // For selectable input types ("text", "search"), only select the hint if
        // it's at the end of the input value. For non-selectable types ("email",
        // "number"), always select the hint.
        shouldSelectHint = utils_1.isSelectable(currentTarget)
            ? currentTarget.selectionStart === currentTarget.value.length
            : true;
    }
    if (key === 'Tab') {
        // Prevent input from blurring on TAB.
        e.preventDefault();
        shouldSelectHint = true;
    }
    return typeof shouldSelect === 'function'
        ? shouldSelect(shouldSelectHint, e)
        : shouldSelectHint;
}
exports.defaultShouldSelect = defaultShouldSelect;
var useHint = function (_a) {
    var children = _a.children, shouldSelect = _a.shouldSelect;
    invariant_1.default(react_1.default.Children.count(children) === 1, '`useHint` expects one child.');
    var _b = Context_1.useTypeaheadContext(), hintText = _b.hintText, initialItem = _b.initialItem, inputNode = _b.inputNode, onAdd = _b.onAdd;
    var hintRef = react_1.useRef(null);
    var onKeyDown = function (e) {
        if (hintText && initialItem && defaultShouldSelect(e, shouldSelect)) {
            onAdd(initialItem);
        }
        children.props.onKeyDown && children.props.onKeyDown(e);
    };
    react_1.useEffect(function () {
        copyStyles(inputNode, hintRef.current);
    });
    return {
        child: react_1.cloneElement(children, __assign(__assign({}, children.props), { onKeyDown: onKeyDown })),
        hintRef: hintRef,
        hintText: hintText,
    };
};
exports.useHint = useHint;
var Hint = function (_a) {
    var className = _a.className, props = __rest(_a, ["className"]);
    var _b = exports.useHint(props), child = _b.child, hintRef = _b.hintRef, hintText = _b.hintText;
    return (react_1.default.createElement("div", { className: className, style: {
            display: 'flex',
            flex: 1,
            height: '100%',
            position: 'relative',
        } },
        child,
        react_1.default.createElement("input", { "aria-hidden": true, className: "rbt-input-hint", ref: hintRef, readOnly: true, style: {
                backgroundColor: 'transparent',
                borderColor: 'transparent',
                boxShadow: 'none',
                color: 'rgba(0, 0, 0, 0.54)',
                left: 0,
                pointerEvents: 'none',
                position: 'absolute',
                top: 0,
                width: '100%',
            }, tabIndex: -1, value: hintText })));
};
exports.default = Hint;
