import type { Placement } from 'popper.js';
import PropTypes from 'prop-types';
import { CSSProperties, ReactNode, Ref } from 'react';
export declare enum Align {
    JUSTIFY = "justify",
    LEFT = "left",
    RIGHT = "right"
}
export interface OverlayRenderProps {
    innerRef: Ref<any>;
    inputHeight: number;
    scheduleUpdate: () => void;
    style: CSSProperties;
}
export interface OverlayProps {
    align: Align;
    children: (props: OverlayRenderProps) => ReactNode;
    dropup: boolean;
    flip: boolean;
    isMenuShown: boolean;
    positionFixed: boolean;
    referenceElement?: HTMLElement;
}
export declare function getPlacement(props: Pick<OverlayProps, 'align' | 'dropup'>): Placement;
declare const Overlay: {
    ({ referenceElement, ...props }: OverlayProps): JSX.Element | null;
    propTypes: {
        /**
         * Specify menu alignment. The default value is `justify`, which makes the
         * menu as wide as the input and truncates long values. Specifying `left`
         * or `right` will align the menu to that side and the width will be
         * determined by the length of menu item values.
         */
        align: PropTypes.Requireable<Align>;
        children: PropTypes.Validator<(...args: any[]) => any>;
        /**
         * Specify whether the menu should appear above the input.
         */
        dropup: PropTypes.Requireable<boolean>;
        /**
         * Whether or not to automatically adjust the position of the menu when it
         * reaches the viewport boundaries.
         */
        flip: PropTypes.Requireable<boolean>;
        isMenuShown: PropTypes.Requireable<boolean>;
        positionFixed: PropTypes.Requireable<boolean>;
        referenceElement: PropTypes.Requireable<Element>;
    };
    defaultProps: {
        align: Align;
        dropup: boolean;
        flip: boolean;
        isMenuShown: boolean;
        positionFixed: boolean;
    };
};
export default Overlay;
