"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPlacement = exports.Align = void 0;
var prop_types_1 = __importDefault(require("prop-types"));
var react_1 = __importDefault(require("react"));
var react_popper_1 = require("react-popper");
var utils_1 = require("../utils");
var Align;
(function (Align) {
    Align["JUSTIFY"] = "justify";
    Align["LEFT"] = "left";
    Align["RIGHT"] = "right";
})(Align = exports.Align || (exports.Align = {}));
// `Element` is not defined during server-side rendering, so shim it here.
/* istanbul ignore next */
var SafeElement = typeof Element === 'undefined' ? utils_1.noop : Element;
var propTypes = {
    /**
     * Specify menu alignment. The default value is `justify`, which makes the
     * menu as wide as the input and truncates long values. Specifying `left`
     * or `right` will align the menu to that side and the width will be
     * determined by the length of menu item values.
     */
    align: prop_types_1.default.oneOf(Object.values(Align)),
    children: prop_types_1.default.func.isRequired,
    /**
     * Specify whether the menu should appear above the input.
     */
    dropup: prop_types_1.default.bool,
    /**
     * Whether or not to automatically adjust the position of the menu when it
     * reaches the viewport boundaries.
     */
    flip: prop_types_1.default.bool,
    isMenuShown: prop_types_1.default.bool,
    positionFixed: prop_types_1.default.bool,
    // @ts-ignore
    referenceElement: prop_types_1.default.instanceOf(SafeElement),
};
var defaultProps = {
    align: Align.JUSTIFY,
    dropup: false,
    flip: false,
    isMenuShown: false,
    positionFixed: false,
};
function getModifiers(props) {
    return {
        computeStyles: {
            enabled: true,
            fn: function (data) {
                return __assign(__assign({}, data), { styles: __assign(__assign({}, data.styles), { 
                        // Use the following condition instead of `align === 'justify'`
                        // since it allows the component to fall back to justifying the
                        // menu width if `align` is undefined.
                        width: props.align !== Align.RIGHT && props.align !== Align.LEFT
                            ? // Set the popper width to match the target width.
                                data.offsets.reference.width + "px"
                            : data.styles.width }) });
            },
        },
        flip: {
            enabled: props.flip,
        },
        preventOverflow: {
            escapeWithReference: true,
        },
    };
}
function getPlacement(props) {
    var x = props.align === Align.RIGHT ? 'end' : 'start';
    var y = props.dropup ? 'top' : 'bottom';
    return y + "-" + x;
}
exports.getPlacement = getPlacement;
var Overlay = function (_a) {
    var referenceElement = _a.referenceElement, props = __rest(_a, ["referenceElement"]);
    if (!props.isMenuShown) {
        return null;
    }
    return (react_1.default.createElement(react_popper_1.Popper, { modifiers: getModifiers(props), placement: getPlacement(props), positionFixed: props.positionFixed, referenceElement: referenceElement }, function (_a) {
        var ref = _a.ref, popperProps = __rest(_a, ["ref"]);
        return props.children(__assign(__assign({}, popperProps), { innerRef: ref, inputHeight: referenceElement ? referenceElement.offsetHeight : 0 }));
    }));
};
Overlay.propTypes = propTypes;
Overlay.defaultProps = defaultProps;
exports.default = Overlay;
