"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var prop_types_1 = __importDefault(require("prop-types"));
var react_1 = __importDefault(require("react"));
var Highlighter_1 = __importDefault(require("./Highlighter"));
var Menu_1 = __importDefault(require("./Menu"));
var MenuItem_1 = __importDefault(require("./MenuItem"));
var utils_1 = require("../utils");
var propTypes = {
    /**
     * Provides the ability to specify a prefix before the user-entered text to
     * indicate that the selection will be new. No-op unless `allowNew={true}`.
     */
    newSelectionPrefix: prop_types_1.default.node,
    /**
     * Prompt displayed when large data sets are paginated.
     */
    paginationText: prop_types_1.default.node,
    /**
     * Provides a hook for customized rendering of menu item contents.
     */
    renderMenuItemChildren: prop_types_1.default.func,
};
var defaultProps = {
    newSelectionPrefix: 'New selection: ',
    paginationText: 'Display additional results...',
    renderMenuItemChildren: function (option, props) { return (react_1.default.createElement(Highlighter_1.default, { search: props.text }, utils_1.getOptionLabel(option, props.labelKey))); },
};
var TypeaheadMenu = function (props) {
    var labelKey = props.labelKey, newSelectionPrefix = props.newSelectionPrefix, options = props.options, paginationText = props.paginationText, renderMenuItemChildren = props.renderMenuItemChildren, menuProps = __rest(props, ["labelKey", "newSelectionPrefix", "options", "paginationText", "renderMenuItemChildren"]);
    var renderMenuItem = function (option, position) {
        var label = utils_1.getOptionLabel(option, labelKey);
        var menuItemProps = {
            disabled: !!utils_1.getOptionProperty(option, 'disabled'),
            label: label,
            option: option,
            position: position,
        };
        if (utils_1.getOptionProperty(option, 'customOption')) {
            return (react_1.default.createElement(MenuItem_1.default, __assign({}, menuItemProps, { className: "rbt-menu-custom-option", key: position, label: label }),
                newSelectionPrefix,
                react_1.default.createElement(Highlighter_1.default, { search: menuProps.text }, label)));
        }
        if (utils_1.getOptionProperty(option, 'paginationOption')) {
            return (react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(Menu_1.default.Divider, null),
                react_1.default.createElement(MenuItem_1.default, __assign({}, menuItemProps, { className: "rbt-menu-pagination-option", label: 
                    // TODO: Fix how (aria-)labels are passed to `MenuItem`.
                    // `paginationText` can be a ReactNode.
                    utils_1.isString(paginationText) ? paginationText : '' }), paginationText)));
        }
        return (react_1.default.createElement(MenuItem_1.default, __assign({}, menuItemProps, { key: position }), renderMenuItemChildren(option, props, position)));
    };
    return react_1.default.createElement(Menu_1.default, __assign({}, menuProps), options.map(renderMenuItem));
};
TypeaheadMenu.propTypes = propTypes;
TypeaheadMenu.defaultProps = defaultProps;
exports.default = TypeaheadMenu;
