"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectedType = exports.optionType = exports.labelKeyType = exports.isRequiredForA11y = exports.inputPropsType = exports.ignoreDiacriticsType = exports.highlightOnlyResultType = exports.defaultSelectedType = exports.defaultInputValueType = exports.deprecated = exports.caseSensitiveType = exports.checkPropType = exports.sizeType = void 0;
var prop_types_1 = __importDefault(require("prop-types"));
var utils_1 = require("./utils");
var types_1 = require("./types");
var INPUT_PROPS_BLACKLIST = [
    { alt: 'onBlur', prop: 'onBlur' },
    { alt: 'onInputChange', prop: 'onChange' },
    { alt: 'onFocus', prop: 'onFocus' },
    { alt: 'onKeyDown', prop: 'onKeyDown' },
];
exports.sizeType = prop_types_1.default.oneOf(Object.values(types_1.Size));
/**
 * Allows additional warnings or messaging related to prop validation.
 */
function checkPropType(validator, callback) {
    return function (props, propName, componentName) {
        var _a;
        prop_types_1.default.checkPropTypes((_a = {}, _a[propName] = validator, _a), props, 'prop', componentName);
        utils_1.isFunction(callback) && callback(props, propName, componentName);
    };
}
exports.checkPropType = checkPropType;
function caseSensitiveType(props) {
    var caseSensitive = props.caseSensitive, filterBy = props.filterBy;
    utils_1.warn(!caseSensitive || typeof filterBy !== 'function', 'Your `filterBy` function will override the `caseSensitive` prop.');
}
exports.caseSensitiveType = caseSensitiveType;
function deprecated(validator, reason) {
    return function (props, propName, componentName) {
        var _a;
        if (props[propName] != null) {
            utils_1.warn(false, "The `" + propName + "` prop is deprecated. " + reason);
        }
        return prop_types_1.default.checkPropTypes((_a = {}, _a[propName] = validator, _a), props, 'prop', componentName);
    };
}
exports.deprecated = deprecated;
function defaultInputValueType(props) {
    var defaultInputValue = props.defaultInputValue, defaultSelected = props.defaultSelected, multiple = props.multiple, selected = props.selected;
    var name = defaultSelected.length ? 'defaultSelected' : 'selected';
    utils_1.warn(!(!multiple &&
        defaultInputValue &&
        (defaultSelected.length || (selected && selected.length))), "`defaultInputValue` will be overridden by the value from `" + name + "`.");
}
exports.defaultInputValueType = defaultInputValueType;
function defaultSelectedType(props) {
    var defaultSelected = props.defaultSelected, multiple = props.multiple;
    utils_1.warn(multiple || defaultSelected.length <= 1, 'You are passing multiple options to the `defaultSelected` prop of a ' +
        'Typeahead in single-select mode. The selections will be truncated to a ' +
        'single selection.');
}
exports.defaultSelectedType = defaultSelectedType;
function highlightOnlyResultType(_a) {
    var allowNew = _a.allowNew, highlightOnlyResult = _a.highlightOnlyResult;
    utils_1.warn(!(highlightOnlyResult && allowNew), '`highlightOnlyResult` will not work with `allowNew`.');
}
exports.highlightOnlyResultType = highlightOnlyResultType;
function ignoreDiacriticsType(props) {
    var filterBy = props.filterBy, ignoreDiacritics = props.ignoreDiacritics;
    utils_1.warn(ignoreDiacritics || typeof filterBy !== 'function', 'Your `filterBy` function will override the `ignoreDiacritics` prop.');
}
exports.ignoreDiacriticsType = ignoreDiacriticsType;
function inputPropsType(_a) {
    var inputProps = _a.inputProps;
    if (!(inputProps &&
        Object.prototype.toString.call(inputProps) === '[object Object]')) {
        return;
    }
    // Blacklisted properties.
    INPUT_PROPS_BLACKLIST.forEach(function (_a) {
        var alt = _a.alt, prop = _a.prop;
        var msg = alt ? " Use the top-level `" + alt + "` prop instead." : null;
        utils_1.warn(!inputProps[prop], "The `" + prop + "` property of `inputProps` will be ignored." + msg);
    });
}
exports.inputPropsType = inputPropsType;
function isRequiredForA11y(props, propName, componentName) {
    utils_1.warn(props[propName] != null, "The prop `" + propName + "` is required to make `" + componentName + "` " +
        'accessible for users of assistive technologies such as screen readers.');
}
exports.isRequiredForA11y = isRequiredForA11y;
function labelKeyType(_a) {
    var allowNew = _a.allowNew, labelKey = _a.labelKey;
    utils_1.warn(!(utils_1.isFunction(labelKey) && allowNew), '`labelKey` must be a string when `allowNew={true}`.');
}
exports.labelKeyType = labelKeyType;
exports.optionType = prop_types_1.default.oneOfType([
    prop_types_1.default.object,
    prop_types_1.default.string,
]);
function selectedType(_a) {
    var multiple = _a.multiple, onChange = _a.onChange, selected = _a.selected;
    utils_1.warn(multiple || !selected || selected.length <= 1, 'You are passing multiple options to the `selected` prop of a Typeahead ' +
        'in single-select mode. This may lead to unexpected behaviors or errors.');
    utils_1.warn(!selected || (selected && utils_1.isFunction(onChange)), 'You provided a `selected` prop without an `onChange` handler. If you ' +
        'want the typeahead to be uncontrolled, use `defaultSelected`. ' +
        'Otherwise, set `onChange`.');
}
exports.selectedType = selectedType;
