"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fast_deep_equal_1 = __importDefault(require("fast-deep-equal"));
var getOptionProperty_1 = __importDefault(require("./getOptionProperty"));
var nodash_1 = require("./nodash");
var stripDiacritics_1 = __importDefault(require("./stripDiacritics"));
var warn_1 = __importDefault(require("./warn"));
function isMatch(input, string, props) {
    var searchStr = input;
    var str = string;
    if (!props.caseSensitive) {
        searchStr = searchStr.toLowerCase();
        str = str.toLowerCase();
    }
    if (props.ignoreDiacritics) {
        searchStr = stripDiacritics_1.default(searchStr);
        str = stripDiacritics_1.default(str);
    }
    return str.indexOf(searchStr) !== -1;
}
/**
 * Default algorithm for filtering results.
 */
function defaultFilterBy(option, props) {
    var filterBy = props.filterBy, labelKey = props.labelKey, multiple = props.multiple, selected = props.selected, text = props.text;
    // Don't show selected options in the menu for the multi-select case.
    if (multiple && selected.some(function (o) { return fast_deep_equal_1.default(o, option); })) {
        return false;
    }
    if (nodash_1.isFunction(labelKey) && isMatch(text, labelKey(option), props)) {
        return true;
    }
    var fields = filterBy.slice();
    if (nodash_1.isString(labelKey)) {
        // Add the `labelKey` field to the list of fields if it isn't already there.
        if (fields.indexOf(labelKey) === -1) {
            fields.unshift(labelKey);
        }
    }
    if (nodash_1.isString(option)) {
        warn_1.default(fields.length <= 1, 'You cannot filter by properties when `option` is a string.');
        return isMatch(text, option, props);
    }
    return fields.some(function (field) {
        var value = getOptionProperty_1.default(option, field);
        if (!nodash_1.isString(value)) {
            warn_1.default(false, 'Fields passed to `filterBy` should have string values. Value will ' +
                'be converted to a string; results may be unexpected.');
            value = String(value);
        }
        return isMatch(text, value, props);
    });
}
exports.default = defaultFilterBy;
