"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.escapeStringRegexp = void 0;
var invariant_1 = __importDefault(require("invariant"));
var stripDiacritics_1 = __importDefault(require("./stripDiacritics"));
var CASE_INSENSITIVE = 'i';
var COMBINING_MARKS = /[\u0300-\u036F]/;
// Export for testing.
function escapeStringRegexp(str) {
    invariant_1.default(typeof str === 'string', '`escapeStringRegexp` expected a string.');
    // Escape characters with special meaning either inside or outside character
    // sets. Use a simple backslash escape when it’s always valid, and a \unnnn
    // escape when the simpler form would be disallowed by Unicode patterns’
    // stricter grammar.
    return str.replace(/[|\\{}()[\]^$+*?.]/g, '\\$&').replace(/-/g, '\\x2d');
}
exports.escapeStringRegexp = escapeStringRegexp;
function getMatchBounds(subject, str) {
    var search = new RegExp(escapeStringRegexp(stripDiacritics_1.default(str)), CASE_INSENSITIVE);
    var matches = search.exec(stripDiacritics_1.default(subject));
    if (!matches) {
        return null;
    }
    var start = matches.index;
    var matchLength = matches[0].length;
    // Account for combining marks, which changes the indices.
    if (COMBINING_MARKS.test(subject)) {
        // Starting at the beginning of the subject string, check for the number of
        // combining marks and increment the start index whenever one is found.
        for (var ii = 0; ii <= start; ii++) {
            if (COMBINING_MARKS.test(subject[ii])) {
                start += 1;
            }
        }
        // Similarly, increment the length of the match string if it contains a
        // combining mark.
        for (var ii = start; ii <= start + matchLength; ii++) {
            if (COMBINING_MARKS.test(subject[ii])) {
                matchLength += 1;
            }
        }
    }
    return {
        end: start + matchLength,
        start: start,
    };
}
exports.default = getMatchBounds;
