"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var invariant_1 = __importDefault(require("invariant"));
var getStringLabelKey_1 = __importDefault(require("./getStringLabelKey"));
var hasOwnProperty_1 = __importDefault(require("./hasOwnProperty"));
var nodash_1 = require("./nodash");
/**
 * Retrieves the display string from an option. Options can be the string
 * themselves, or an object with a defined display string. Anything else throws
 * an error.
 */
function getOptionLabel(option, labelKey) {
    // Handle internally created options first.
    if (!nodash_1.isString(option) &&
        (hasOwnProperty_1.default(option, 'paginationOption') ||
            hasOwnProperty_1.default(option, 'customOption'))) {
        return option[getStringLabelKey_1.default(labelKey)];
    }
    var optionLabel;
    if (nodash_1.isFunction(labelKey)) {
        optionLabel = labelKey(option);
    }
    else if (nodash_1.isString(option)) {
        optionLabel = option;
    }
    else {
        // `option` is an object and `labelKey` is a string.
        optionLabel = option[labelKey];
    }
    invariant_1.default(nodash_1.isString(optionLabel), 'One or more options does not have a valid label string. Check the ' +
        '`labelKey` prop to ensure that it matches the correct option key and ' +
        'provides a string for filtering and display.');
    return optionLabel;
}
exports.default = getOptionLabel;
